# Changelog

## [v1.3.1](https://github.com/RegioHelden/django-temporalio/tree/v1.3.1) (2025-07-03)

[Full Changelog](https://github.com/RegioHelden/django-temporalio/compare/v1.3.0...v1.3.1)

**Fixed bugs:**

- fix: sync_temporalio_schedules management command is working properly now. Use proper variables in `lambda` passed to the `schedule_handle.update()`. [\#46](https://github.com/RegioHelden/django-temporalio/pull/46) (@krayevidi)

**Merged pull requests:**

- Update uv to 0.7.19 [\#45](https://github.com/RegioHelden/django-temporalio/pull/45) (@regiohelden-dev)
- Update uv to 0.7.18 [\#44](https://github.com/RegioHelden/django-temporalio/pull/44) (@regiohelden-dev)
- Update uv to 0.7.17 [\#43](https://github.com/RegioHelden/django-temporalio/pull/43) (@regiohelden-dev)
- Update uv to 0.7.15 [\#42](https://github.com/RegioHelden/django-temporalio/pull/42) (@regiohelden-dev)

## [v1.3.0](https://github.com/RegioHelden/django-temporalio/tree/v1.3.0) (2025-06-25)

[Full Changelog](https://github.com/RegioHelden/django-temporalio/compare/v1.2.0...v1.3.0)

**Implemented enhancements:**

- feat: add "heartbeat" context manager. [\#38](https://github.com/RegioHelden/django-temporalio/pull/38) (@bodja)
- Update reusable workflows [\#35](https://github.com/RegioHelden/django-temporalio/pull/35) (@lociii)
- Bump django in test dependencies from 5.2 to 5.2.2 [\#31](https://github.com/RegioHelden/django-temporalio/pull/31) (@dependabot[bot])
- Bump setuptools from 78.1.0 to 78.1.1 [\#28](https://github.com/RegioHelden/django-temporalio/pull/28) (@dependabot[bot])
- Migrate to resuable workflows, align with RH library setup [\#9](https://github.com/RegioHelden/django-temporalio/pull/9) (@lociii)

**Merged pull requests:**

- Updates GitHub reusable workflows to 2.2.4 [\#37](https://github.com/RegioHelden/django-temporalio/pull/37) (@regiohelden-dev)
- Update uv to 0.7.14 [\#36](https://github.com/RegioHelden/django-temporalio/pull/36) (@regiohelden-dev)
- Updates ruff VSCode integration to 2025.24.0 [\#34](https://github.com/RegioHelden/django-temporalio/pull/34) (@regiohelden-dev)
- Update uv to 0.7.13 [\#33](https://github.com/RegioHelden/django-temporalio/pull/33) (@regiohelden-dev)
- Update uv to 0.7.12 [\#32](https://github.com/RegioHelden/django-temporalio/pull/32) (@regiohelden-dev)
- Update uv to 0.7.11 [\#30](https://github.com/RegioHelden/django-temporalio/pull/30) (@regiohelden-dev)
- Update uv to 0.7.8 [\#29](https://github.com/RegioHelden/django-temporalio/pull/29) (@regiohelden-dev)
- Update uv to 0.7.7 [\#27](https://github.com/RegioHelden/django-temporalio/pull/27) (@regiohelden-dev)
- Update uv to 0.7.6 [\#26](https://github.com/RegioHelden/django-temporalio/pull/26) (@regiohelden-dev)
- Update uv to 0.7.5 [\#25](https://github.com/RegioHelden/django-temporalio/pull/25) (@regiohelden-dev)
- Update uv to 0.7.4 [\#24](https://github.com/RegioHelden/django-temporalio/pull/24) (@regiohelden-dev)
- Update uv to 0.7.3 [\#23](https://github.com/RegioHelden/django-temporalio/pull/23) (@regiohelden-dev)
- Updates from modulesync [\#22](https://github.com/RegioHelden/django-temporalio/pull/22) (@regiohelden-dev)
- Updates from modulesync [\#21](https://github.com/RegioHelden/django-temporalio/pull/21) (@regiohelden-dev)
- Updates from modulesync [\#20](https://github.com/RegioHelden/django-temporalio/pull/20) (@regiohelden-dev)
- Updates from modulesync [\#19](https://github.com/RegioHelden/django-temporalio/pull/19) (@regiohelden-dev)
- Updates from modulesync [\#18](https://github.com/RegioHelden/django-temporalio/pull/18) (@regiohelden-dev)
- Updates from modulesync [\#17](https://github.com/RegioHelden/django-temporalio/pull/17) (@regiohelden-dev)
- Updates from modulesync [\#16](https://github.com/RegioHelden/django-temporalio/pull/16) (@regiohelden-dev)
- Updates from modulesync [\#15](https://github.com/RegioHelden/django-temporalio/pull/15) (@regiohelden-dev)
- Bump regiohelden/github-reusable-workflows from 2.0.0 to 2.1.0 [\#14](https://github.com/RegioHelden/django-temporalio/pull/14) (@dependabot[bot])
- Updates from modulesync  [\#13](https://github.com/RegioHelden/django-temporalio/pull/13) (@regiohelden-dev)
- Preparations for modulesync rollout [\#12](https://github.com/RegioHelden/django-temporalio/pull/12) (@lociii)
- Renovate [\#6](https://github.com/RegioHelden/django-temporalio/pull/6) (@lociii)
- add possibility to override all client connection settings [\#5](https://github.com/RegioHelden/django-temporalio/pull/5) (@krayevidi)
- Bump django from 5.0.7 to 5.0.8 [\#4](https://github.com/RegioHelden/django-temporalio/pull/4) (@dependabot[bot])
- Temporalio encapsulation [\#3](https://github.com/RegioHelden/django-temporalio/pull/3) (@krayevidi)

## 1.2.0 (2024-10-17)

**Breaking changes:**

* replaced `NAMESPACE` and `URL` settings with `CLIENT_CONFIG` setting

## 1.1.0 (2024-05-30)

**Implemented enhancements:**

* add Temporal.io related code encapsulation 

## 1.0.0 (2024-05-16)

**Implemented enhancements:**

* Initial release


